# aastex

[![tests](https://github.com/sun-data/aastex/actions/workflows/tests.yml/badge.svg)](https://github.com/sun-data/aastex/actions/workflows/tests.yml)
[![codecov](https://codecov.io/gh/sun-data/aastex/graph/badge.svg?token=c9VYZtRAO8)](https://codecov.io/gh/sun-data/aastex)
[![Black](https://github.com/sun-data/aastex/actions/workflows/black.yml/badge.svg)](https://github.com/sun-data/aastex/actions/workflows/black.yml)
[![Documentation Status](https://readthedocs.org/projects/aastex/badge/?version=latest)](https://aastex.readthedocs.io/en/latest/?badge=latest)
[![PyPI version](https://badge.fury.io/py/aastex.svg)](https://badge.fury.io/py/aastex)

This Python library extends [PyLaTeX](https://github.com/JelteF/PyLaTeX) to support the
[AASTeX LaTeX package](https://journals.aas.org/aastex-package-for-manuscript-preparation/).

## Installation

`aastex` is available on PyPI and can be installed using `pip`:

```bash
pip install aastex
```
